@@ -1126,10 +1126,6 @@ namespace Oxygen
         const ColorUtils::Rgba base( ColorUtils::alphaColor( light, 0.85 ) );
         const ColorUtils::Rgba dark( ColorUtils::shade( darkColor(color), shade ) );
 
-        // mask dimensions
-        const double ic = 3.6 + 0.5*_slabThickness;
-        const double is = 14.0 - 2.0*ic;
-
         // bevel, part 1
         {
 
@@ -1149,7 +1145,6 @@ namespace Oxygen
             cairo_pattern_add_color_stop( pattern, 0.9, base );
             cairo_set_source( context, pattern );
             cairo_rounded_rectangle( context, 3.0, 3.0, 8, 8, 3.5 );
-            cairo_ellipse_negative( context, ic, ic, is, is );
             cairo_fill( context );
 
         }
@@ -1168,12 +1163,21 @@ namespace Oxygen
             cairo_pattern_add_color_stop( pattern, 0.9, base );
             cairo_set_source( context, pattern );
             cairo_ellipse( context, 3.6, 3.6, 6.8, 6.8 );
-
-            cairo_ellipse_negative( context, ic, ic, is, is );
             cairo_fill( context );
 
         }
 
+        // inside mask
+        cairo_save( context );
+        cairo_set_operator( context, CAIRO_OPERATOR_DEST_OUT );
+        cairo_set_source( context, ColorUtils::Rgba::black() );
+
+        const double ic( 3.6 + 0.5*_slabThickness );
+        const double is( 14.0 - 2.0*ic );
+        cairo_ellipse( context, ic, ic, is, is );
+        cairo_fill( context );
+        cairo_restore( context );
+
     }
 
     //___________________________________________________________________________________________
@@ -1218,10 +1222,6 @@ namespace Oxygen
         const double x(m+1);
         const double y(m+offset+1);
 
-        // mask dimensions
-        const double ic = 3.6 + 0.5*_slabThickness - 1;
-        const double is = double(size) - 2.0*ic;
-
         Cairo::Pattern pattern( cairo_pattern_create_radial(x, y, m ) );
         for (int i = 0; i < 8; i++)
         {
@@ -1234,7 +1234,6 @@ namespace Oxygen
         cairo_pattern_add_color_stop( pattern, 1, ColorUtils::Rgba::transparent( base ) );
         cairo_set_source( context, pattern );
         cairo_ellipse( context, 0, 0, size, size );
-        cairo_ellipse_negative( context, ic, ic, is, is );
         cairo_fill( context );
 
     }
@@ -1244,12 +1243,7 @@ namespace Oxygen
     {
 
         const double m( double(size)*0.5 );
-
-        // mask dimensions
-        const double ic = 3.6 + 0.5*_slabThickness - 1;
-        const double is = double(size) - 2.0*ic;
-
-        const double w( 4 );
+        const double w( 3 );
 
         const double bias( _glowBias * double(14)/size );
 
@@ -1257,26 +1251,28 @@ namespace Oxygen
         const double gm( m + bias - 0.9 );
         const double k0( (m-w+bias) / gm );
 
-
-        const double x(m);
-        const double y(m);
-
-        Cairo::Pattern pattern( cairo_pattern_create_radial(x, y, m ) );
+        Cairo::Pattern pattern( cairo_pattern_create_radial( m, m, gm ) );
         for (int i = 0; i < 8; i++)
         {
             // parabolic pattern
             const double k1( k0 + double(i)*(1.0-k0)/8.0 );
             const double a( 1.0 - sqrt(double(i)/8) );
-            cairo_pattern_add_color_stop( pattern, k1, ColorUtils::alphaColor( base, a*_shadowGain ) );
+            cairo_pattern_add_color_stop( pattern, k1, ColorUtils::alphaColor( base, a ) );
         }
 
         cairo_pattern_add_color_stop( pattern, 1, ColorUtils::Rgba::transparent( base ) );
 
         cairo_set_source( context, pattern );
         cairo_ellipse( context, 0, 0, size, size );
-        cairo_ellipse_negative( context, ic, ic, is, is );
         cairo_fill( context );
 
+        cairo_save( context );
+        cairo_set_operator( context, CAIRO_OPERATOR_DEST_OUT );
+        cairo_set_source( context, ColorUtils::Rgba::black() );
+        cairo_ellipse( context, w, w, size - 2*w, size - 2*w );
+        cairo_fill( context );
+        cairo_restore( context );
+
     }
 
     //________________________________________________________________________________________________________
