@@ -28,10 +28,11 @@
 * MA 02110-1301, USA.
 */
 
-#include "oxygensignal.h"
-#include "oxygentimer.h"
 #include "oxygendatamap.h"
 #include "oxygengtkutils.h"
+#include "oxygenhook.h"
+#include "oxygensignal.h"
+#include "oxygentimer.h"
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -54,6 +55,9 @@ namespace Oxygen
         //! destructor
         virtual ~WindowManager();
 
+        //! initialize hoooks
+        void initializeHooks( void );
+
         //! register widget
         virtual void registerWidget( GtkWidget* );
 
@@ -90,9 +94,6 @@ namespace Oxygen
         //! on button press
         static gboolean wmButtonPress( GtkWidget*, GdkEventButton*, gpointer );
 
-        //! on button release
-        static gboolean wmButtonRelease(GtkWidget*, GdkEventButton*, gpointer );
-
         //! on mouse leave
         static gboolean wmLeave(GtkWidget*, GdkEventCrossing*, gpointer );
 
@@ -105,6 +106,9 @@ namespace Oxygen
         //! delayed drag
         static gboolean startDelayedDrag( gpointer );
 
+        //! mouse button release event hook
+        static gboolean buttonReleaseHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
+
         //@}
 
         //! start dragging widget
@@ -118,7 +122,7 @@ namespace Oxygen
         { if( _drag && _widget ) startDrag( _widget, _x, _y ); }
 
         //! finish dragging widget
-        bool finishDrag( GtkWidget* );
+        bool finishDrag( void );
 
         //! return true if window is dragable
         bool isWindowDragWidget( GtkWidget*, GdkEventButton* );
@@ -145,7 +149,7 @@ namespace Oxygen
 
             //! predicate
             bool operator() (const std::string& objectName ) const
-            { return Gtk::gtk_object_is_a( _object, objectName ); }
+            { return Gtk::g_object_is_a( _object, objectName ); }
 
             private:
 
@@ -188,7 +192,6 @@ namespace Oxygen
             Signal _leaveId;
             Signal _destroyId;
             Signal _pressId;
-            Signal _releaseId;
             Signal _motionId;
             Signal _styleId;
             //@}
@@ -203,6 +206,12 @@ namespace Oxygen
         //! drag mode
         Mode _mode;
 
+        //! true when hooks are initialized
+        bool _hooksInitialized;
+
+        //! mouse button release event hook
+        Hook _buttonReleaseHook;
+
         //! timer
         Timer _timer;
 
